@@ -1,5 +1,6 @@
 from osm2gmns.networkclass.mesonet import MesoNode, MesoLink, MesoNetwork
 from osm2gmns.networkclass.micronet import MicroNode, MicroLink, MicroNetwork
+from osm2gmns.utils.util_geo import offsetLine
 import osm2gmns.settings as og_settings
 from shapely import geometry
 import sys
@@ -50,15 +51,14 @@ class NetGenerator:
             for i in range(mesolink.lanes):
                 lane_offset = (num_of_lane_offset_between_left_most_and_central + i) * self.width_of_lane
                 if lane_offset < -1e-3 or lane_offset > 1e-3:
-                    lane_geometry_xy = mesolink.geometry_xy.parallel_offset(distance=lane_offset, side='right', join_style=2)
-
-                    if isinstance(lane_geometry_xy, geometry.MultiLineString):
-                        coords = []
-                        for line in lane_geometry_xy: coords += line.coords
-                        lane_geometry_xy = geometry.LineString(coords)
-
-                    if lane_offset > 1e-3:
-                        lane_geometry_xy = geometry.LineString(list(lane_geometry_xy.coords)[::-1])
+                    lane_geometry_xy_ = mesolink.geometry_xy.parallel_offset(distance=lane_offset, side='right', join_style=2)
+                    if isinstance(lane_geometry_xy_, geometry.MultiLineString):
+                        lane_geometry_xy = offsetLine(mesolink.geometry_xy, lane_offset)
+                    else:
+                        if lane_offset > 1e-3:
+                            lane_geometry_xy = geometry.LineString(list(lane_geometry_xy_.coords)[::-1])
+                        else:
+                            lane_geometry_xy = lane_geometry_xy_
                 else:
                     lane_geometry_xy = mesolink.geometry_xy
                 lane_geometry_xy_list.append(lane_geometry_xy)
